@@ -18,8 +18,9 @@
 #include <sys/socket.h> 
 
 #define BUFLEN 100
+#define MAX_SECTIONS 100
 
-int strparse(char *string, const char *delim, int sections, ...);
+char **strparse(char *string, const char *delim, int *numsecs);
 
 int esock_new(char *ip, int port);
 char *esock_read(int sockfd);
