@@ -12,13 +12,14 @@
 GtkWidget *text1;
 GtkWidget *text2;
 GtkWidget *text3;
+GtkWidget *text4;
 GtkWidget *mode_update;
 GtkWidget *mode_offline;
 GtkWidget *checkbutton;
 GtkWidget *checkbutton1;
 
 char path_xgdip2[256];
-char gdip_savepass, gdip_autoquit, gdip_server[50], gdip_username[20], gdip_pass[20];
+char gdip_savepass, gdip_autoquit, gdip_server[50], gdip_username[20], gdip_domain[50], gdip_pass[33];
 
 void connect_to (GtkWidget *widget);
 void restore_window (GtkWidget *thisw, GtkWidget *widget);
